#!/usr/bin/perl 

#check_dummy_custom.pl
#
#Description:
#
#Author:
#        Otavio Honorio (otavio.honorio@opservices.com.br)
#
#16-03-2010 : Created 
#10-07-2012 : Alterado para suportar min e max, valor inicial e randomico

use strict;
use Getopt::Long;
use POSIX;
use File::Basename;

#--------------------------------------------------
# Setting environment
#-------------------------------------------------- 
$ENV{"USER"}="opuser";
$ENV{"HOME"}="/home/opuser";

#--------------------------------------------------
# Global variables
#--------------------------------------------------
our $name = basename($0, ".pl");
our $version = "1.1";
our $path = "/usr/local/opmon/libexec";
our $temp_log = "$path/$name.log";
our ($opt_help, $opt_verbose, $opt_version, $opt_warn, $opt_crit, $command, $out, $status, $text, $unit, $var, $min, $max, $inicial, $random);

my @metrics = ("", "", ""); # Generate performance data.
my @return = (); # Return to complete performance data.


sub main {

getoption();
$command = `$path/check_dummy2 texto 0 $inicial $random 1 2 unidade variavel 100`;
chomp($command);

   if ($command =~ m/[[0-9][0-9].[0-9][0-9]/){
       $status = $&;
       if ($status < $opt_warn){
                print "OK - $text $status$var $unit | $text=$status$var;$opt_warn;$opt_crit;$min;$max\n";
                exit(0);
        }elsif (($status >= $opt_warn) && ($& < $opt_crit)){
                print "WARNNING - $text $status$var $unit | $text=$status$var;$opt_warn;$opt_crit;$min;$max\n";
                exit(1);
        }elsif ($status >= $opt_crit){
                print "CRITICAL - $text $status$var $unit | $text=$status$var;$opt_warn;$opt_crit;$min;$max\n";
                exit(2);
        }else{
                print "UNKNOW - Unable to check the service\n";
                exit(3);
        }
   }
}
#--------------------------------------------------------------------------------------
sub getoption  {
     Getopt::Long::Configure('bundling');
     GetOptions(
            'V|version'               => \$opt_version,
            'c|critical=f'              => \$opt_crit,
            'h|help'                  => \$opt_help,
            'v|verbose=i'               => \$opt_verbose,
            'w|warning=f'               => \$opt_warn,
	    't|text=s'			=> \$text,
	    'u|unit=s'			=> \$unit,
	    'i|variable=s'		=> \$var,
	    'ini=i'		=> \$inicial,
	    'ran=i'		=> \$random,
	    'min=i'		=> \$min,
	    'max=i'		=> \$max,
        );

     if($opt_help){

             printHelp();
              exit(1);

     }

     if($opt_version){

             print "$name.pl - '$version'\n";
             exit(1);
 
     }

     if(!$opt_verbose){

             $opt_verbose = 0;

     }

     if ((!$opt_warn) or (!$opt_crit) or (!$text) or (!$unit) or (!$var)){
             printUsage();
              exit(1);

     }


}

#--------------------------------------------------------------------------------------
sub logger {

        return (0) if (not defined $opt_verbose);

        my $msg = shift (@_);
        my $perf = "";
        my $log = "$path/$name.log";
        my $counter = 0;


        foreach(@metrics){

		$perf .= "$_=$return[$counter];$opt_warn;$opt_crit;; ";
	   	$counter++;

        }

        my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=localtime(time);
        $wday++;
        $yday++;
        $mon++;
        $year+=1900;
        $isdst++;

        if ($opt_verbose == 0){

		if (@metrics){

    			 print "$msg | $perf\n";

		}

		   	else{

		       	 print "$msg\n";
	    	}

	    }

	    elsif ($opt_verbose == 1){

			print "$msg\n";

	    }

	else {
           open(LOG, ">>$log");
           printf LOG ("%02i/%02i/%i - %02i:%02i:%02i => %s\n",$mday,$mon,$year,$hour,$min,$sec,$msg);
           close(LOG);
        }

}
#--------------------------------------------------------------------------------------

sub printUsage {

       print <<EOB

Usage: $name.pl [OPTION]...

        -V, --version      Show version
        -c, --critical     Threshold to critical
        -h, --help         Show help
        -w, --warning      Threshold to warning
	-t, --text	   Text for the name of service
        -u, --unit	   Unit for the service
        -i, --var	   Variable for dates of performance
        --min              Variable for min dates of performance
        --max              Variable for max dates of performance
        --ini              Variable for inicial dates
        --ran              Variable for random dates
        -v, --verbose      0 = Print out to see in OpMon(Default)
                           1 = Print out in console for debug
			   2 = Send log to file

EOB

}
#--------------------------------------------------------------------------------------

sub printHelp {

		my $help = <<'HELP';

	 Generic plugin for demonstrations of services for OpMon
	Example Usage: check_dummy_custom.pl -t Temperature -u G -i Celcius -w 50 -c 60 
        -V, --version      Show version
        -c, --critical     Threshold to critical
        -h, --help         Show help
        -w, --warning      Threshold to warning
        -t, --text         Text for the name of service
        -u, --unit         Unit for the service
        -i, --var          Variable for dates of performance
        --min              Variable for min dates of performance
        --max              Variable for max dates of performance
        --ini              Variable for inicial dates
        --ran              Variable for random dates
        -v, --verbose      0 = Print out to see in OpMon(Default)
                           1 = Print out in console for debug
                           2 = Send log to file


HELP

		print $help;

}
#--------------------------------------------------------------------------------------
&main

