#!/usr/bin/perl

($warning, $critical) = @ARGV;

use Getopt::Long;
use POSIX;
use File::Basename;
use DBI;

our $version = "2.0";

our $conf_file = "/usr/local/opmon/etc/db.php";
our ( $dbuser, $dbpass, $dbhost, $opt_recover,$opt_help,$opt_version, $sql,$sth,@row,$host_check_disabled,$host_notification_disabled,$service_check_disabled,$service_notification_disabled );

sub _main {
	# Read database config
	_read_conf();

	# Connect to the database
	my $dbh = DBI->connect ( "dbi:mysql:dbname=opmon4;host=$dbhost", $dbuser, $dbpass)
		or do	{	print "Cannot connect to database: $DBI::errstr\n";
            exit(3);
					};

	$total=0;
	# get hosts info
	$sql="select notifications_enabled,active_checks_enabled from host_status;";
	$sth = $dbh->prepare($sql);
	$sth->execute or do
								{
									print "Cannot run query: $DBI::errstr\n";
            			exit(3);
								};
	$host_check_disabled=0;
	$host_notification_disabled=0;
	while (@row = $sth->fetchrow_array) {
		$total++;
		if ($row[0]==0) {
			$host_notification_disabled++;
		}
		if ($row[1]==0) {
			$host_check_disabled++;
		}
	}
	$sth->finish;

	# get services info	
	$sql="select notifications_enabled,active_checks_enabled from service_status;";
	$sth = $dbh->prepare($sql);
	$sth->execute or do
								{
									print "Cannot run query: $DBI::errstr\n";
            			exit(3);
								};
	$service_check_disabled=0;
	$service_notification_disabled=0;
	while (@row = $sth->fetchrow_array) {
		$total++;
		if ($row[0]==0) {
			$service_notification_disabled++;
		}
		if ($row[1]==0) {
			$service_check_disabled++;
		}
	}
	$sth->finish;
	
	$total_check_disabled=$host_check_disabled+$service_check_disabled;
	$total_notification_disabled=$host_notification_disabled+$service_notification_disabled;
	$total_disabled=$total_check_disabled+$total_notification_disabled;
	$pct_disabled=($total_disabled*100)/$total;
	$pct_disabled=sprintf("%.02f",$pct_disabled);

	if ($pct_disabled>=$critical) {
		print "Critical - $pct_disabled% de elementos desabilitados (TOTAL = $total_disabled, onde $host_check_disabled checagens de hosts, $service_check_disabled checagens de servicos, $host_notification_disabled notificacoes de hosts e $service_notification_disabled notificacoes de servicos) |Desabilitados=$pct_disabled%;$warning;$critical;0;100\n";
		exit (2);
	}elsif ($pct_disabled>=$warning) {
		print "Warning - $pct_disabled% de elementos desabilitados (TOTAL = $total_disabled, onde $host_check_disabled checagens de hosts, $service_check_disabled checagens de servicos, $host_notification_disabled notificacoes de hosts e $service_notification_disabled notificacoes de servicos) |Desabilitados=$pct_disabled%;$warning;$critical;0;100\n";
		exit(1);
	}else{
		print "OK - $pct_disabled% de elementos desabilitados (TOTAL = $total_disabled, onde $host_check_disabled checagens de hosts, $service_check_disabled checagens de servicos, $host_notification_disabled notificacoes de hosts e $service_notification_disabled notificacoes de servicos) |Desabilitados=$pct_disabled%;$warning;$critical;0;100\n";
		exit(0);
	}
}

sub _read_conf {
   open( FILE, "$conf_file" );
   while(<FILE>) {
      $dbuser = $1 if (m/DBUSER\s*=\s*[\'\"]*([^\'\"]*)[\'\"]*;/);
      $dbpass = $1 if (m/DBPASS\s*=\s*[\'\"]*([^\'\"]*)[\'\"]*;/);
      $dbhost = $1 if (m/DBHOST\s*=\s*[\'\"]*([^\'\"]*)[\'\"]*;/);
   }
   close(FILE);
}

&_main;
