#!/usr/bin/perl 

#Description:
#
#Author:
#        Boris Vasquez (boris.vasquez@opservices.com.br)
#
#00-00-2010 : Created 

use strict;
use Getopt::Long;
use POSIX;
use File::Basename;
use Date::Manip;

#--------------------------------------------------
# Setting environment
#-------------------------------------------------- 
$ENV{"USER"}="opuser";
$ENV{"HOME"}="/home/opuser";

#--------------------------------------------------
# Global variables
#--------------------------------------------------
our $name = basename($0, ".pl");
our $version = "1.0";
our $path = "/usr/local/opmon/libexec";
our $temp_log = "$path/$name.log";
our ($opt_help, $opt_verbose, $opt_version, $opt_warn, $opt_crit);

our @metrics = ("", "", ""); # Generate performance data.
our @return = (); # Return to complete performance data.

our (@licenca,$date_conv);
our ($date_sys,$date_diff,$err,$atr);
our ($sec,$min,$hour) = localtime(time);
$date_sys = strftime "%y-%m-%d",localtime;
$date_sys = "20".$date_sys;

sub main {

     getoption();
     @licenca = `/usr/local/opmon/libexec/opservices/opmon_license_properties.php`;
     my $expire = $& if ($licenca[0] =~ /\d+/);
     my $date_expire = $& if ($licenca[2] =~ /\d+/);
     my $hosts = $& if ($licenca[7] =~ /\d+/);
     my $services = $& if ($licenca[17] =~ /\d+/);

     if ($expire > 0){
       $date_conv = strftime "%y-%m-%d",localtime($date_expire);
       $date_conv =  "20".$date_conv;
       my $date_parse1 = ParseDate("$date_sys");
       my $date_parse2 = ParseDate("$date_conv");
#      YY:MM:WK:DD:HH:MM:SS     
       $date_diff = DateCalc($date_parse1,$date_parse2,1);
       
       my ($y,$mes,$w,$d,$h,$m,$s) = split (/:/,$date_diff);
       
       $atr = 0;
       print "$date_conv\n";
       if ($date_diff =~/\+/){
	$atr++;
       }
       $d += ($w*7);       
       if ($atr == 0){
	print "Critical - Licenca expirada a $d dia(s). Data:$date_conv Hosts: $hosts Servicos: $services\n";
	exit(2);
       }elsif($atr > 0){
	if($d <= $opt_crit){
	  print "Critical - Faltam $d para a licenca expirar. Data:$date_conv Hosts: $hosts Servicos: $services\n";
	  exit(2);
	}elsif($d <= $opt_warn){
	  print "Warning - Faltam $d para a licenca expirar. Data:$date_conv Hosts: $hosts Servicos: $services\n";
	  exit(1);
	 }elsif($d > $opt_warn){
	   print "OK - Faltam $d para a licenca expirar. Data:$date_conv Hosts: $hosts Servicos: $services\n";
	   exit(0);
	 }else{
	   print "Desconhecido - Nao foi possível verificar a licenca.\n";
	   exit(3);
	 }
       }
       
     }elsif($expire ==0){
      
      print "OK - Licenca nao expira.\n";
      exit(0);
     }else{
      print "Desconhecido - Nao foi possivel verificar a licenca.\n";
      exit(3);
     }
}
#--------------------------------------------------------------------------------------
sub getoption  {
     Getopt::Long::Configure('bundling');
     GetOptions(
            'c|critical=f'              => \$opt_crit,
            'h|help'                  => \$opt_help,
            'w|warning=f'               => \$opt_warn,
        );

     if($opt_help){
             printHelp();
              exit(1);
     }

     if($opt_version){
             print "$name.pl - '$version'\n";
             exit(1);
      }

     if(!$opt_verbose){
             $opt_verbose = 0;
     }

    if ((!$opt_warn) or (not defined $opt_crit)){
            printUsage();
             exit(1);
    }

}

#--------------------------------------------------------------------------------------
sub logger {

        return (0) if (not defined $opt_verbose);

        my $msg = shift (@_);
        my $perf = "";
        my $log = "$path/$name.log";
        my $counter = 0;

        foreach(@metrics){
                $perf .= "$_=$return[$counter];$opt_warn;$opt_crit;; ";
                $counter++;
        }
        my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=localtime(time);
        $wday++;
        $yday++;
        $mon++;
        $year+=1900;
        $isdst++;
        if ($opt_verbose == 0){
                if (@metrics){
                         print "$msg | $perf\n";
                }
                else{
                         print "$msg\n";
                }
            }
            elsif ($opt_verbose == 1){
                        print "$msg\n";
            }

        else {
           open(LOG, ">>$log");
           printf LOG ("%02i/%02i/%i - %02i:%02i:%02i => %s\n",$mday,$mon,$year,$hour,$min,$sec,$msg);
           close(LOG);
        }

}
#--------------------------------------------------------------------------------------

sub printUsage {
       print <<EOB
Usage: $name.pl [OPTION]...

        -c, --critical     Threshold to critical
        -w, --warning      Threshold to warning, set 0 for alert on day expire


EOB
}
#--------------------------------------------------------------------------------------

sub printHelp {
                my $help = <<'HELP';
                Insert help program
HELP
                print $help;
}
#--------------------------------------------------------------------------------------
sub print_error {
    my $msg = shift;
    print "Critical - $msg\n";
    exit (2);
}

#--------------------------------------------------------------------------------------
&main

