#!/usr/bin/perl
#notify_by_zenvia
#Description:
#       OpMon Notifycation via zenvia
#Author:
#	Estevan Ramalho (estevan.ramalho@opservices.com.br)
#Version:
#	1.0 24-05-2013: Initial release
#	1.1 27-05-2013: Included SERVICEOUTPUT

use strict;
use Getopt::Long;
use POSIX;
use LWP::UserAgent;
use HTTP::Request;
use HTTP::Cookies;

$ENV{"USER"}="opuser";
$ENV{"HOME"}="/home/opuser";

our $version = "1.1";
our $name = "notify_by_zenvia";
our $path = "/usr/local/opmon/libexec/opservices/";
our ($opt_version, $opt_help, $opt_debug, $opt_user, $opt_pass, $opt_from, $opt_to, $opt_detail, $opt_env);
our ($opt_date, $opt_Ntype);
our ($opt_Hname, $opt_Haddr, $opt_Hstate);
our ($opt_Sname, $opt_Sstate);

our $usage ='
Usage: '. $0 .' [OPTION]...
Send a SMS notification via zenvia, for hosts and services.

General Options:
        -e, --env		Get data from environmental variables (service|host|test)
        -U, --username		Zenvia account
        -P, --password		Zenvia code
        -f, --from		Sender number		
        -t, --to		Recipient number		

Extra Options:

        -h, --help              Display this help and exit
        -v, --version           Output version information and exit

        -d, --debug     	1 = Debug
                        	2 = Generate log file

Send email to suporte@opservices.com.br if you have questions
regarding use of this software. To submit patches or suggest improvements,
send email to suporte@opservices.com.br.
Please include version information with all correspondence (when possible,
use output from the --version option of the plugin itself).

For more information about the return codes please consult the site below:
http://www.zenvia.com.br/desenvolvedores/documentacao/metodos-da-api/envio-de-sms-unico-http-webservice/
';

sub main {
        # Get options
        getOptions();
	logger($opt_debug, "----- Starting -----");
	# Get the OpMon Environmental Variables
	get_env();
	logger($opt_debug, "----- Environmental Variables -----");
	logger($opt_debug, $opt_Ntype); 
        logger($opt_debug, $opt_date);
        logger($opt_debug, $opt_Hname);
        logger($opt_debug, "----- Access Info -----");
        logger($opt_debug, "User: $opt_user");
        logger($opt_debug, "Pass: $opt_pass");
	# Get the Ticket Description
	my $msg = get_msg();
	logger($opt_debug, "Message:\n$msg");
	# Make the HTTP connection
	my $ua  = LWP::UserAgent->new;
	my $agent = "Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9) Gecko/2008052912 Firefox/3.0";
	$ua->agent("$agent");
	# Send Message
	logger($opt_debug, "----- Send Message -----");
	my $return = send_msg($ua,$msg);
	if ($return == "3"){
		print "Unknown - The message could not be sent\n";
		exit ($return);
	}elsif($return == "2"){	
		print "Critital - The message could not be sent\n";
		exit ($return);	
	}else{
		print "OK - The message has been sent\n";
		exit ($return);
	}
}
#---------------------------------------------------------------------------
sub send_msg{
	# HTTP connection parameters
	my $ua = shift;
	my $msg = shift;
	my $host = "http://api.zenvia360.com.br/GatewayIntegration/msgSms.do";
	my $url = "$host?dispatch=send&account=$opt_user&code=$opt_pass&msg=$msg&from=$opt_from&to=$opt_to";
	logger($opt_debug, "\nFull Url:\n\"".$url."\"");
	# Login URL
	my $request = new HTTP::Request GET => "$url";
	my $response = $ua->request($request);
	my $return = $response->content;
	logger($opt_debug, "\nResponse:\n".$response->as_string()."\n");
	my @ret = split(' - ',$return);
	if ($ret[0] gt "900"){ 
		return(3);
	} elsif ($ret[0] gt "000") {
		return(2);
	} else {
		return(0);
	}
} 
#--------------------------------------------------------------------------
sub getOptions {  #command line options
        Getopt::Long::Configure('bundling');
        GetOptions(
                'v|version'     => \$opt_version,
                'h|help'        => \$opt_help,
                'd|debug=i'     => \$opt_debug,
                'e|env=s'       => \$opt_env,
                'f|from=s'      => \$opt_from,
                't|to=s'	=> \$opt_to,
                'U|user=s'      => \$opt_user,
                'P|password=s'  => \$opt_pass,
        )or do {
                print $usage;
		exit(0);
        };

        if ($opt_version) {
                print $name." ".$version."\n";
                exit(0);
        }
        if ($opt_help){
                print $usage;
		exit(0);
	}
	if ((!$opt_to) || (!$opt_from) || (!$opt_user) || (!$opt_pass) || ($opt_env !~ /host|service|test/)){
		print $usage;
		exit(3);
	} 
        if ( ($opt_debug) and ($opt_debug !~ /1|2/ ) ){
                usage("Option Missing:\t-d|--debug\t(1|2)\n");
        }
}
#--------------------------------------------------------------------------
sub get_env(){
        logger($opt_debug,"Loading Environmental Variables");
	if ($opt_env =~ /test/){
	        $opt_Ntype  = 'NAGIOS_NOTIFICATIONTYPE';
	        $opt_date   = 'NAGIOS_SHORTDATETIME';
	        $opt_Hname  = 'NAGIOS_HOSTNAME';
	        $opt_Haddr  = 'NAGIOS_HOSTADDRESS';
                $opt_Hstate = 'NAGIOS_HOSTSTATE';
                $opt_Sname  = 'NAGIOS_SERVICEDESC';
                $opt_Sstate = 'NAGIOS_SERVICESTATE';
		$opt_detail = 'NAGIOS_SERVICEOUTPUT';
	} else {
        	$opt_Ntype = $ENV{'NAGIOS_NOTIFICATIONTYPE'};
        	$opt_date  = $ENV{'NAGIOS_SHORTDATETIME'};
        	$opt_Hname = $ENV{'NAGIOS_HOSTNAME'};
        	if ($opt_env =~ /host/){
        		$opt_Haddr  = $ENV{'NAGIOS_HOSTADDRESS'};
        	        $opt_Hstate = $ENV{'NAGIOS_HOSTSTATE'};
        	}else{
        	        $opt_Sname  = $ENV{'NAGIOS_SERVICEDESC'};
        	        $opt_Sstate = $ENV{'NAGIOS_SERVICESTATE'};
			$opt_detail = $ENV{'NAGIOS_SERVICEOUTPUT'};
        	}
	}
        return;
}
#--------------------------------------------------------------------------
sub get_msg {
	my $msg;
	if ($opt_env =~ /host/){
		$msg = "$opt_Ntype\nHost: $opt_Hname\nState: $opt_Hstate\nAddress: $opt_Haddr\nDate/Time: $opt_date";
	}elsif ($opt_env =~ /service/){
		$msg = "$opt_Ntype\nHost: $opt_Hname\nService: $opt_Sname\nState: $opt_Sstate\nDetail: $opt_detail\nDate/Time: $opt_date";
	}else {
		$msg = "$opt_Ntype\nHost: $opt_Hname\nService: $opt_Sname\nState: $opt_Sstate\nDetail: $opt_detail\nDate/Time: $opt_date";
	}
	return ($msg);
}
#--------------------------------------------------------------------------
sub logger {
        my $opt = shift;
        my $msg = shift;
        my $log = "$path/$name.log";
        my $date = strftime("%d/%m/%Y - %H:%M:%S",localtime);
        if ($opt == 1){
			print "$msg\n";
        }elsif ($opt == 2) {
			open(LOG, ">>$log");
			print LOG "$date => $msg\n";
			close(LOG);
        }
}
#--------------------------------------------------------------------------
&main;
